@@ -147,6 +147,7 @@ void conboy_midgard_object2note(MgdObject *object, Note *note)
 			NULL);
 
 	/* Set last change and create date */
+
 	MidgardMetadata *metadata = object->metadata;
 	GValue rev_val = {0, };
 	g_value_init(&rev_val, MGD_TYPE_TIMESTAMP);
@@ -158,19 +159,13 @@ void conboy_midgard_object2note(MgdObject *object, Note *note)
 	const gchar *created = midgard_timestamp_get_string(&c_val);
 	const gchar *revised = midgard_timestamp_get_string(&rev_val);
 
-	if (created) {
-	
-		GTimeVal time_;
-		g_time_val_from_iso8601 (created, &time_);
-		note->create_date = time(time_.tv_sec);	
-	}
+	if (created) 
+		note->create_date = get_iso8601_time_in_seconds(created);	
 
 	if (revised) {
 	
-		GTimeVal rtime_;	
-		//g_time_val_from_iso8601 (revised, &rtime_);
-		//note->last_change_date = time(time_.tv_sec);	
-		//note->last_metadata_change_date = time(time_.tv_sec);
+		note->last_change_date = get_iso8601_time_in_seconds(revised);	
+		note->last_metadata_change_date = get_iso8601_time_in_seconds(revised);
 	}
 
 	g_value_unset(&rev_val);
